#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Feb  9 14:47:56 2023

@author: lubo

International System of Units Constants 
"""
# %% SI defining constants
LightSpeed = 299792458 # [m/s]
PlanckConst = 6.62607015e-34 # [J⋅s]
ElemCharge = 1.602176634e-19 # [C]
BoltzConst = 1.380649e-23 # [J/K]
AvogaConst = 6.02214076e23 # [1/mol]

# %% Non-SI units accepted for use with SI units
Dalton = 1.660539040e-27 # [kg]
'atomic mass in kg'
electronVolt =  1.602176634e-19 # [J]
